# jinfo
Extensible bio/informatics library for hackers


Objects:
- DNASeq, RNASeq and AASeq

Functions:
- one_hot_dna, random_dna, DNASeq_from_NCBI


TODO:
- DNASeq.find_CDS()
- DNASeq_from_NCBI()


NOTES:
Python package structure:
- define classes and functions to their own files
- add import statements to the __init__.py file
- then can import all/selected classes using import jinformatics

Python packaging reference:
https://python-packaging.readthedocs.io/en/latest/minimal.html
